@@ -13,14 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 import unittest
 import logging
-import six
 import struct
 import inspect
-from nose.tools import ok_, eq_, nottest
 
 from os_ken.ofproto import ether
 from os_ken.lib.packet import packet
@@ -48,42 +44,42 @@ class TestLLDPMandatoryTLV(unittest.TestCase):
 
     def test_get_tlv_type(self):
         buf = b'\x02\x07\x04\x00\x04\x96\x1f\xa7\x26'
-        eq_(lldp.LLDPBasicTLV.get_type(buf), lldp.LLDP_TLV_CHASSIS_ID)
+        self.assertEqual(lldp.LLDPBasicTLV.get_type(buf), lldp.LLDP_TLV_CHASSIS_ID)
 
     def test_parse_without_ethernet(self):
         buf = self.data[ethernet.ethernet._MIN_LEN:]
         (lldp_pkt, cls, rest_buf) = lldp.lldp.parser(buf)
-        eq_(len(rest_buf), 0)
+        self.assertEqual(len(rest_buf), 0)
 
         tlvs = lldp_pkt.tlvs
-        eq_(tlvs[0].tlv_type, lldp.LLDP_TLV_CHASSIS_ID)
-        eq_(tlvs[0].len, 7)
-        eq_(tlvs[0].subtype, lldp.ChassisID.SUB_MAC_ADDRESS)
-        eq_(tlvs[0].chassis_id, b'\x00\x04\x96\x1f\xa7\x26')
-        eq_(tlvs[1].tlv_type, lldp.LLDP_TLV_PORT_ID)
-        eq_(tlvs[1].len, 4)
-        eq_(tlvs[1].subtype, lldp.PortID.SUB_INTERFACE_NAME)
-        eq_(tlvs[1].port_id, b'1/3')
-        eq_(tlvs[2].tlv_type, lldp.LLDP_TLV_TTL)
-        eq_(tlvs[2].len, 2)
-        eq_(tlvs[2].ttl, 120)
-        eq_(tlvs[3].tlv_type, lldp.LLDP_TLV_END)
+        self.assertEqual(tlvs[0].tlv_type, lldp.LLDP_TLV_CHASSIS_ID)
+        self.assertEqual(tlvs[0].len, 7)
+        self.assertEqual(tlvs[0].subtype, lldp.ChassisID.SUB_MAC_ADDRESS)
+        self.assertEqual(tlvs[0].chassis_id, b'\x00\x04\x96\x1f\xa7\x26')
+        self.assertEqual(tlvs[1].tlv_type, lldp.LLDP_TLV_PORT_ID)
+        self.assertEqual(tlvs[1].len, 4)
+        self.assertEqual(tlvs[1].subtype, lldp.PortID.SUB_INTERFACE_NAME)
+        self.assertEqual(tlvs[1].port_id, b'1/3')
+        self.assertEqual(tlvs[2].tlv_type, lldp.LLDP_TLV_TTL)
+        self.assertEqual(tlvs[2].len, 2)
+        self.assertEqual(tlvs[2].ttl, 120)
+        self.assertEqual(tlvs[3].tlv_type, lldp.LLDP_TLV_END)
 
     def test_parse(self):
         buf = self.data
         pkt = packet.Packet(buf)
         i = iter(pkt)
 
-        eq_(type(next(i)), ethernet.ethernet)
-        eq_(type(next(i)), lldp.lldp)
+        self.assertEqual(type(next(i)), ethernet.ethernet)
+        self.assertEqual(type(next(i)), lldp.lldp)
 
     def test_tlv(self):
         tlv = lldp.ChassisID(subtype=lldp.ChassisID.SUB_MAC_ADDRESS,
                              chassis_id=b'\x00\x04\x96\x1f\xa7\x26')
-        eq_(tlv.tlv_type, lldp.LLDP_TLV_CHASSIS_ID)
-        eq_(tlv.len, 7)
+        self.assertEqual(tlv.tlv_type, lldp.LLDP_TLV_CHASSIS_ID)
+        self.assertEqual(tlv.len, 7)
         (typelen, ) = struct.unpack('!H', b'\x02\x07')
-        eq_(tlv.typelen, typelen)
+        self.assertEqual(tlv.typelen, typelen)
 
     def test_serialize_without_ethernet(self):
         tlv_chassis_id = lldp.ChassisID(subtype=lldp.ChassisID.SUB_MAC_ADDRESS,
@@ -95,7 +91,7 @@ class TestLLDPMandatoryTLV(unittest.TestCase):
         tlvs = (tlv_chassis_id, tlv_port_id, tlv_ttl, tlv_end)
         lldp_pkt = lldp.lldp(tlvs)
 
-        eq_(lldp_pkt.serialize(None, None),
+        self.assertEqual(lldp_pkt.serialize(None, None),
             self.data[ethernet.ethernet._MIN_LEN:])
 
     def test_serialize(self):
@@ -118,7 +114,7 @@ class TestLLDPMandatoryTLV(unittest.TestCase):
         lldp_pkt = lldp.lldp(tlvs)
         pkt.add_protocol(lldp_pkt)
 
-        eq_(len(pkt.protocols), 2)
+        self.assertEqual(len(pkt.protocols), 2)
 
         pkt.serialize()
 
@@ -128,9 +124,9 @@ class TestLLDPMandatoryTLV(unittest.TestCase):
         data_len = len(self.data)
         pkt_data_lldp = pkt.data[:data_len]
         pkt_data_pad = pkt.data[data_len:]
-        eq_(b'\x00' * (60 - data_len), pkt_data_pad)
+        self.assertEqual(b'\x00' * (60 - data_len), pkt_data_pad)
 
-        eq_(self.data, pkt_data_lldp)
+        self.assertEqual(self.data, pkt_data_lldp)
 
     def test_to_string(self):
         chassis_id = lldp.ChassisID(subtype=lldp.ChassisID.SUB_MAC_ADDRESS,
@@ -185,8 +181,8 @@ class TestLLDPMandatoryTLV(unittest.TestCase):
         lldp_str = _lldp_str % (lldp.lldp.__name__,
                                 tlvs_str)
 
-        eq_(str(lldp_pkt), lldp_str)
-        eq_(repr(lldp_pkt), lldp_str)
+        self.assertEqual(str(lldp_pkt), lldp_str)
+        self.assertEqual(repr(lldp_pkt), lldp_str)
 
     def test_json(self):
         chassis_id = lldp.ChassisID(subtype=lldp.ChassisID.SUB_MAC_ADDRESS,
@@ -199,7 +195,7 @@ class TestLLDPMandatoryTLV(unittest.TestCase):
         lldp1 = lldp.lldp(tlvs)
         jsondict = lldp1.to_jsondict()
         lldp2 = lldp.lldp.from_jsondict(jsondict['lldp'])
-        eq_(str(lldp1), str(lldp2))
+        self.assertEqual(str(lldp1), str(lldp2))
 
 
 class TestLLDPOptionalTLV(unittest.TestCase):
@@ -250,49 +246,49 @@ class TestLLDPOptionalTLV(unittest.TestCase):
         pkt = packet.Packet(buf)
         i = iter(pkt)
 
-        eq_(type(next(i)), ethernet.ethernet)
+        self.assertEqual(type(next(i)), ethernet.ethernet)
         lldp_pkt = next(i)
-        eq_(type(lldp_pkt), lldp.lldp)
+        self.assertEqual(type(lldp_pkt), lldp.lldp)
 
         tlvs = lldp_pkt.tlvs
 
         # Port Description
-        eq_(tlvs[3].tlv_type, lldp.LLDP_TLV_PORT_DESCRIPTION)
-        eq_(tlvs[3].port_description, b'Summit300-48-Port 1001\x00')
+        self.assertEqual(tlvs[3].tlv_type, lldp.LLDP_TLV_PORT_DESCRIPTION)
+        self.assertEqual(tlvs[3].port_description, b'Summit300-48-Port 1001\x00')
 
         # System Name
-        eq_(tlvs[4].tlv_type, lldp.LLDP_TLV_SYSTEM_NAME)
-        eq_(tlvs[4].system_name, b'Summit300-48\x00')
+        self.assertEqual(tlvs[4].tlv_type, lldp.LLDP_TLV_SYSTEM_NAME)
+        self.assertEqual(tlvs[4].system_name, b'Summit300-48\x00')
 
         # System Description
 
-        eq_(tlvs[5].tlv_type, lldp.LLDP_TLV_SYSTEM_DESCRIPTION)
-        eq_(tlvs[5].system_description,
+        self.assertEqual(tlvs[5].tlv_type, lldp.LLDP_TLV_SYSTEM_DESCRIPTION)
+        self.assertEqual(tlvs[5].system_description,
             b'Summit300-48 - Version 7.4e.1 (Build 5) '
             + b'by Release_Master 05/27/05 04:53:11\x00')
 
         # SystemCapabilities
-        eq_(tlvs[6].tlv_type, lldp.LLDP_TLV_SYSTEM_CAPABILITIES)
-        eq_(tlvs[6].system_cap & lldp.SystemCapabilities.CAP_MAC_BRIDGE,
+        self.assertEqual(tlvs[6].tlv_type, lldp.LLDP_TLV_SYSTEM_CAPABILITIES)
+        self.assertEqual(tlvs[6].system_cap & lldp.SystemCapabilities.CAP_MAC_BRIDGE,
             lldp.SystemCapabilities.CAP_MAC_BRIDGE)
-        eq_(tlvs[6].enabled_cap & lldp.SystemCapabilities.CAP_MAC_BRIDGE,
+        self.assertEqual(tlvs[6].enabled_cap & lldp.SystemCapabilities.CAP_MAC_BRIDGE,
             lldp.SystemCapabilities.CAP_MAC_BRIDGE)
-        eq_(tlvs[6].system_cap & lldp.SystemCapabilities.CAP_TELEPHONE, 0)
-        eq_(tlvs[6].enabled_cap & lldp.SystemCapabilities.CAP_TELEPHONE, 0)
+        self.assertEqual(tlvs[6].system_cap & lldp.SystemCapabilities.CAP_TELEPHONE, 0)
+        self.assertEqual(tlvs[6].enabled_cap & lldp.SystemCapabilities.CAP_TELEPHONE, 0)
 
         # Management Address
-        eq_(tlvs[7].tlv_type, lldp.LLDP_TLV_MANAGEMENT_ADDRESS)
-        eq_(tlvs[7].addr_len, 7)
-        eq_(tlvs[7].addr, b'\x00\x01\x30\xf9\xad\xa0')
-        eq_(tlvs[7].intf_num, 1001)
+        self.assertEqual(tlvs[7].tlv_type, lldp.LLDP_TLV_MANAGEMENT_ADDRESS)
+        self.assertEqual(tlvs[7].addr_len, 7)
+        self.assertEqual(tlvs[7].addr, b'\x00\x01\x30\xf9\xad\xa0')
+        self.assertEqual(tlvs[7].intf_num, 1001)
 
         # Organizationally Specific
-        eq_(tlvs[8].tlv_type, lldp.LLDP_TLV_ORGANIZATIONALLY_SPECIFIC)
-        eq_(tlvs[8].oui, b'\x00\x12\x0f')  # IEEE 802.3
-        eq_(tlvs[8].subtype, 0x02)  # Power Via MDI
+        self.assertEqual(tlvs[8].tlv_type, lldp.LLDP_TLV_ORGANIZATIONALLY_SPECIFIC)
+        self.assertEqual(tlvs[8].oui, b'\x00\x12\x0f')  # IEEE 802.3
+        self.assertEqual(tlvs[8].subtype, 0x02)  # Power Via MDI
 
         # End
-        eq_(tlvs[16].tlv_type, lldp.LLDP_TLV_END)
+        self.assertEqual(tlvs[16].tlv_type, lldp.LLDP_TLV_END)
 
     def test_parse_corrupted(self):
         buf = self.data
@@ -336,13 +332,13 @@ class TestLLDPOptionalTLV(unittest.TestCase):
         lldp_pkt = lldp.lldp(tlvs)
         pkt.add_protocol(lldp_pkt)
 
-        eq_(len(pkt.protocols), 2)
+        self.assertEqual(len(pkt.protocols), 2)
 
         pkt.serialize()
 
         # self.data has many organizationally specific TLVs
-        data = six.binary_type(pkt.data[:-2])
-        eq_(data, self.data[:len(data)])
+        data = bytes(pkt.data[:-2])
+        self.assertEqual(data, self.data[:len(data)])
 
     def test_to_string(self):
         chassis_id = lldp.ChassisID(subtype=lldp.ChassisID.SUB_MAC_ADDRESS,
@@ -494,8 +490,8 @@ class TestLLDPOptionalTLV(unittest.TestCase):
         lldp_str = _lldp_str % (lldp.lldp.__name__,
                                 tlvs_str)
 
-        eq_(str(lldp_pkt), lldp_str)
-        eq_(repr(lldp_pkt), lldp_str)
+        self.assertEqual(str(lldp_pkt), lldp_str)
+        self.assertEqual(repr(lldp_pkt), lldp_str)
 
     def test_json(self):
         chassis_id = lldp.ChassisID(subtype=lldp.ChassisID.SUB_MAC_ADDRESS,
@@ -524,4 +520,4 @@ class TestLLDPOptionalTLV(unittest.TestCase):
         lldp1 = lldp.lldp(tlvs)
         jsondict = lldp1.to_jsondict()
         lldp2 = lldp.lldp.from_jsondict(jsondict['lldp'])
-        eq_(str(lldp1), str(lldp2))
+        self.assertEqual(str(lldp1), str(lldp2))
